<?php
namespace Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services;

class AprovacaoAlcadasService
{
    protected $fileServerFilesUrl;
    
    public function __construct($connection, $fileServerFilesUrl)
    {
        $this->connection           = $connection;
        $this->fileServerFilesUrl   = $fileServerFilesUrl;
    }
    
    public function getAlcadas($conditions)
    {
        $sql = "SELECT NRAPROVALCADA, NRCONFIGALCADA, NMALCADA, IDTIPOVRAPROV, CDFILDEST, CDFILLANC,
                       NRDEMANDA, IDTPDEMANDA, IDCLASSIFIC, IDAPROVADO, DTINCLUSAO, APROVADOR,
                       VRAPROVCMP, NMFILDEST, VRTOTALAF, DSMOTVAFALCADA, NRINSJURFORN, NMRAZSOCFORN,
                       NMFANTFORN, NRORG, DTPROGENTAF, NVL(VRORCAMENTO, 0) VRORCAMENTO, 
                       NVL(VRREALIZADO, 0) VRREALIZADO, NVL(VRDIFERENCA, 0) VRDIFERENCA
                  FROM TABLE(APROVA_ALCADAS(P_CDFILIAL        => :P_CDFILIAL,
                                            P_CDOPERADOR      => :P_CDOPERADOR,
                                            P_IDAPROVADO      => :P_IDAPROVADO,
                                            P_IDCLASSIFIC     => :P_IDCLASSIFIC,
                                            P_NRCONFIGALCADA  => :P_NRCONFIGALCADA,
                                            P_DTINCLUSAO_INI  => :P_DTINCLUSAO_INI,
                                            P_DTINCLUSAO_FIN  => :P_DTINCLUSAO_FIN,
                                            P_TDTINCLUSAO     => :P_TDTINCLUSAO,
                                            P_DTENTREGAAF_INI => :P_DTENTREGAAF_INI,
                                            P_DTENTREGAAF_FIN => :P_DTENTREGAAF_FIN,
                                            P_TDTENTREGAAF    => :P_TDTENTREGAAF))";
        try {
            $std = $this->connection->prepare($sql);
            $std->execute(
                array (
                    'P_CDFILIAL'        => $conditions['CDFILIAL'],
                    'P_CDOPERADOR'      => $conditions['CDOPERADOR'],
                    'P_IDAPROVADO'      => $conditions['IDAPROVADO'],
                    'P_IDCLASSIFIC'     => $conditions['IDCLASSIFIC'],
                    'P_NRCONFIGALCADA'  => $conditions['NRCONFIGALCADA'],
                    'P_DTINCLUSAO_INI'  => $conditions['P_DTINCLUSAO_INI'],
                    'P_DTINCLUSAO_FIN'  => $conditions['P_DTINCLUSAO_FIN'],
                    'P_TDTINCLUSAO'     => $conditions['P_TDTINCLUSAO'],
                    'P_DTENTREGAAF_INI' => $conditions['P_DTENTREGAAF_INI'],
                    'P_DTENTREGAAF_FIN' => $conditions['P_DTENTREGAAF_FIN'],
                    'P_TDTENTREGAAF'    => $conditions['P_TDTENTREGAAF'],
                )
            );
            
            return $std->fetchAll();
        } catch(Exception $e) {
            throw $e;
        }
    }
    
    public function defineColumn($IDAPROVADO)
    {
        if ($IDAPROVADO == 'PENDENTE')
            return 1;
        else if ($IDAPROVADO == 'APROVADO')
            return 2;
        else if ($IDAPROVADO == 'RECUSADO')
            return 3;
    }
    
    public function getFileServerUrlAlcadas() 
    {
        return $this->fileServerFilesUrl;
    }
    
    public function downloadAnexoFile($arquivo, $fileName) 
    {
        try {
            if(isset($arquivo)) {
                $contentLenghtArray = array();
                
                foreach(get_headers($arquivo) as $value) {
                    if(strpos($value, 'Content-Length: ') !== false) {
                    	array_push($contentLenghtArray, str_replace('Content-Length: ', '',$value));
                    }
                };
                
                $contentLenght = max($contentLenghtArray);
                
                $key = $this->hasErrorOnResponse(get_headers($arquivo));
                
                if(is_numeric($key)) {
                    throw new \Exception(get_headers($arquivo)[$key]);
                }
                
                $tipo = null;
    
                switch (strtolower(substr(strrchr(basename($arquivo), "."), 1))) {
                    case "gif" : $tipo="image/gif"                    ; break;
                    case "png" : $tipo="image/png"                    ; break;
                    case "jpg" : $tipo="image/jpg"                    ; break;
                    case "wma" : $tipo="audio/mime"                   ; break;
                    case "txt" : $tipo="text/plain"                   ; break;
                    case "rem" : $tipo="text/plain"                   ; break;
                    case "mp3" : $tipo="audio/mpeg"                   ; break;
                    case "mp4" : $tipo="video/mpeg-4"                 ; break;
                    case "pdf" : $tipo="application/pdf"              ; break;
                    case "zip" : $tipo="application/zip"              ; break;
                    case "doc" : $tipo="application/msword"           ; break;
                    case "xls" : $tipo="application/vnd.ms-excel"     ; break;
                    case "exe" : $tipo="application/octet-stream"     ; break;
                    case "ppt" : $tipo="application/vnd.ms-powerpoint"; break;
                    case "php" :                                      ; break;
                    case "htm" :                                      ; break;
                    case "html":                                      ; break;
                }
                
                header("Content-Type: ".$tipo);
                header("Content-Length: ".$contentLenght);
                header("Content-Disposition: attachment; filename=".basename($fileName));
                
                readfile($arquivo);
                
                die();
            } else {
                throw new \Exception('URL não definida.');
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function hasErrorOnResponse($headers)
    {
        $errors = [
            'HTTP/1.1 404 Not Found',
            'HTTP/1.1 500 Internal Server Error',
        ];
        
        foreach ($errors as $error) {
            $key = array_search($error, $headers);
            
            if (is_numeric($key)) {
                return $key;
            }
        }
        
        return false;
    }
}
