<?php

namespace Services;

use Util\SupUtilities;

class OrderAFService
{

    const CDEMPRESA = '01';
    const CDFILLANC = '9999';
    const CDOPERADOR = '000000000987';

    public function __construct(SupUtilities $supUtilities)
    {
        $this->supUtilities = $supUtilities;
    }

    public function generateCodeAutoForn()
    {
        return $this->supUtilities->generateCode('AUTOFORNE');
    }

    public function getFilial($cdFildest)
    {
        $query = "SELECT CDFILIAL, NMFILIAL, NVL(CDFILCENTCMP, CDFILIAL)  CDFILCENTCMP, CDREGIAO FROM FILIAL WHERE CDFILIAL = :P_CDFILDEST";
        $params = array("P_CDFILDEST" => $cdFildest);
        return $this->supUtilities->crud($query, $params);
    }

    public function getAutoFornUsr($usrImportAf, $cdSupplier)
    {
        $query = "SELECT USR_NRIMPORTAF, CDFILDEST, CDFILLANC, NRAUTOFORN FROM AUTOFORNE WHERE USR_NRIMPORTAF = :P_USR_NRIMPORTAF AND CDFORNECED = :P_CDFORNECED";
        $params = array(
            "P_USR_NRIMPORTAF" => $usrImportAf,
            "P_CDFORNECED" => $cdSupplier,
        );
        return $this->supUtilities->crud($query, $params);
    }

    public function getSupplier($cdSupplier)
    {
        $query = "SELECT CDFORNECED, CDFORMPGTO, IDTPFORPGTFO, NMFANTFORN, NRPARCPGTOFO, NRDIAPGFIXFO, IDUTDIAPGTFO FROM FORNECEDOR WHERE CDFORNECED = :P_CDFORNECED";
        $params = array("P_CDFORNECED" => $cdSupplier);
        return $this->supUtilities->crud($query, $params);
    }

    public function getDefaultSuppliers($cdSupplier)
    {
        $query = "SELECT 'S' AS CDPARAMINT, CDFORNECED, CDOPERADOR, DSDIRENVIO, DSHOST, DSLOGIN, DSSENHA, VRINTERVALO FROM USR_PARAMINTEGRA WHERE CDFORNECED = :P_CDFORNECED OR :P_CDFORNECED = 'T'";
        $params = $params = array("P_CDFORNECED" => $cdSupplier);
        return $this->supUtilities->crud($query, $params);
    }

    public function setAutoForn($orderData, $supplier)
    {
        $query = "INSERT INTO AUTOFORNE (CDFILDEST, CDFILLANC, NRAUTOFORN, CDFORNECED, DTAUTOFORN, CDOPERADOR, CDFORMPGTO, IDTPFORPGTAF, IDTIPOEMITAF, CDEMPRESA, NRPARCPGTOAF, NRDIAPGFIXAF, IDUTDIAPGTAF) VALUES (:P_CDFILDEST, :P_CDFILLANC, :P_NRAUTOFORN, :P_CDFORNECED,  TRUNC(SYSDATE), :P_CDOPERADOR, :P_CDFORMPGTO, :P_IDTPFORPGTAF, '1', :P_CDEMPRESA, :P_NRPARCPGTOAF, :P_NRDIAPGFIXAF, :P_IDUTDIAPGTAF)";
        $params = array(
            'P_CDFILLANC' => self::CDFILLANC,
            'P_CDOPERADOR' => self::CDOPERADOR,
            'P_CDEMPRESA' => self::CDEMPRESA,
            'P_CDFILDEST' => $orderData['cdFildest'],
            'P_NRAUTOFORN' => $orderData['nrAutoForn'],
            'P_CDFORNECED' => $supplier['CDFORNECED'],
            'P_CDFORMPGTO' => $supplier['CDFORMPGTO'],
            'P_IDTPFORPGTAF' => $supplier['IDTPFORPGTFO'],
            'P_NRPARCPGTOAF' => $supplier['NRPARCPGTOFO'],
            'P_NRDIAPGFIXAF' => $supplier['NRDIAPGFIXFO'],
            'P_IDUTDIAPGTAF' => $supplier['IDUTDIAPGTFO'],
        );      
        $this->supUtilities->crud($query, $params);
    }

    public function setDeadlinePayment($orderData, $cdSupplier)
    {
        $query = 'INSERT INTO PRAZOPGTAF (CDFILDEST, CDFILLANC, NRAUTOFORN, NRDIASPGTOAF, VRPERCPGTOAF) (SELECT :P_CDFILDEST, :P_CDFILLANC, :P_NRAUTOFORN, NRDIASPGTOFO, VRPERCPGTOFO FROM PRAZOPGTFORN WHERE CDFORNECED = :P_CDFORNECED)';
        $params = array(
            'P_CDFILLANC' => self::CDFILLANC,
            'P_CDFILDEST' => $orderData['cdFildest'],
            'P_NRAUTOFORN' => $orderData['nrAutoForn'],
            'P_CDFORNECED' => $cdSupplier
        );
        $this->supUtilities->crud($query, $params);
    }


}
