CREATE OR REPLACE TRIGGER USR_EXCLUSAO_EXPORTAPEDOL
AFTER DELETE ON PEDIDOEXOL FOR EACH ROW
DECLARE
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   V_NOVOCODIGO    INTEGER;
   V_FILIAL        VARCHAR2(10);
   V_FORMPGTO      VARCHAR(3);
   V_FORNECEDOR    VARCHAR(14);

   V_W6_EMPRESA    VARCHAR2(2);
   V_W6_FILIAL     VARCHAR2(2);
   V_W6_NUM        VARCHAR2(6);
   V_W6_CGC        VARCHAR2(14);
   V_W6_CC         VARCHAR2(9);
   V_W6_CONDPAG    VARCHAR2(3);
   V_W6_TIPO       VARCHAR2(1);
   V_MAIORCOD      INTEGER;
BEGIN
   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
        INTO V_DTGRV, V_HRGRV
        FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   SELECT MAX(CDGRUPFILI)
     INTO V_FILIAL
     FROM FILGRUPFILI
    WHERE CDFILIAL = :OLD.CDFILLANC
      AND USR_IDPROTHEUS = 'S';

   IF NOT V_FILIAL IS NULL THEN
      /* Retorna o sequencial para a tabela */
      BEGIN
         SELECT W6_IDAFPVC.NEXTVAL
           INTO V_NOVOCODIGO
           FROM DUAL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_NOVOCODIGO := 1;
      END;

      BEGIN
         SELECT MAX(W6_IDAFPVC)
         INTO V_MAIORCOD
         FROM USR_ZW6
         WHERE CDFILDEST = :OLD.CDFILDEST
           AND CDFILLANC = :OLD.CDFILLANC
           AND NRPEDEXOL = :OLD.NRPEDEXOL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_MAIORCOD := NULL;
      END;

      IF V_MAIORCOD IS NULL THEN
         BEGIN
            SELECT LPAD(MAX(F.CDFORMPGTO),3,'0'),
                   SUBSTR(replace(replace(replace(MAX(F.NRINSJURFORN), '-', ''),'.',''),'/',''),1,14)
              INTO V_FORMPGTO,
                   V_FORNECEDOR
              FROM FORNECEDOR F, FILIAL FI
             WHERE FI.CDFILIAL = :OLD.CDFILIOPELOG
               AND F.CDFORNECED = FI.CDFORNOPELOG;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_FORMPGTO := NULL;
               V_FORNECEDOR := NULL;
         END;

         INSERT INTO USR_ZW6
             (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
              W6_EMPRESA, W6_FILIAL, W6_NUM,
              W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI,
              W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
         VALUES
          (:OLD.CDFILDEST, :OLD.CDFILLANC, :OLD.NRPEDEXOL, V_NOVOCODIGO,
           SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), SUBSTR(:OLD.NRPEDEXOL, 5, 6),
           V_FORNECEDOR, :OLD.CDFILDEST, V_FORMPGTO, 'N', '1',
           TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
           TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');
      END IF;

      BEGIN
         SELECT W6_IDAFPVC.NEXTVAL
           INTO V_NOVOCODIGO
           FROM DUAL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_NOVOCODIGO := 1;
      END;

      BEGIN
         SELECT W6_EMPRESA, W6_FILIAL, W6_NUM, W6_CGC,
                W6_CC, W6_CONDPAG, W6_TIPO
           INTO V_W6_EMPRESA, V_W6_FILIAL, V_W6_NUM, V_W6_CGC,
                V_W6_CC, V_W6_CONDPAG, V_W6_TIPO
           FROM USR_ZW6
          WHERE CDFILDEST = :OLD.CDFILDEST
            AND CDFILLANC = :OLD.CDFILLANC
            AND NRPEDEXOL = :OLD.NRPEDEXOL
            AND W6_IDAFPVC = V_MAIORCOD;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_W6_EMPRESA := SUBSTR(V_FILIAL, 7, 2);
            V_W6_FILIAL  := SUBSTR(V_FILIAL, 9, 2);
            V_W6_NUM     := SUBSTR(:OLD.NRPEDEXOL, 5, 6);
            V_W6_CGC     := V_FORNECEDOR;
            V_W6_CC      := :OLD.CDFILDEST;
            V_W6_CONDPAG := V_FORMPGTO;
            V_W6_TIPO    := 'N';
      END;

      INSERT INTO USR_ZW6
          (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
           W6_EMPRESA, W6_FILIAL, W6_NUM,
           W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI,
           W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
      VALUES
          (:OLD.CDFILDEST, :OLD.CDFILLANC, :OLD.NRPEDEXOL, V_NOVOCODIGO,
           V_W6_EMPRESA, V_W6_FILIAL, V_W6_NUM,
           V_W6_CGC, V_W6_CC, V_W6_CONDPAG, V_W6_TIPO, '2',
           TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
           TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');

      FOR C_USR_ZW7 IN (
         SELECT CDPRODUTO, DTPROGENPEOL, W7_EMPRESA, W7_FILIAL, W7_NUM,
                W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_DTENTR
           FROM USR_ZW7
          WHERE CDFILDEST = :OLD.CDFILDEST
            AND CDFILLANC = :OLD.CDFILLANC
            AND NRPEDEXOL = :OLD.NRPEDEXOL
            AND W7_IDAFPVI = V_MAIORCOD) LOOP

         INSERT INTO USR_ZW7
              (CDFILDEST, CDFILLANC, NRPEDEXOL, CDPRODUTO, DTPROGENPEOL,
               W7_IDAFPVI, W7_EMPRESA, W7_FILIAL, W7_NUM,
               W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
               W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_DTENTR, W7_TPEDI,
               W7_DTGRV, W7_HRGRV, W7_DTIMP, W7_HRIMP)
         VALUES
              (:OLD.CDFILDEST, :OLD.CDFILLANC, :OLD.NRPEDEXOL, C_USR_ZW7.CDPRODUTO, C_USR_ZW7.DTPROGENPEOL,
               V_NOVOCODIGO, C_USR_ZW7.W7_EMPRESA, C_USR_ZW7.W7_FILIAL, C_USR_ZW7.W7_NUM,
               C_USR_ZW7.W7_CGC, C_USR_ZW7.W7_ITEM, C_USR_ZW7.W7_PRODUTO, C_USR_ZW7.W7_CC, C_USR_ZW7.W7_QTDVEN,
               C_USR_ZW7.W7_PRCVEN, C_USR_ZW7.W7_PRUNIT, C_USR_ZW7.W7_VALOR, C_USR_ZW7.W7_DTENTR, '2', TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
               TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');
      END LOOP;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXCLUSAO_EXPORTAPEDOL','5.09.000'); END;
/
